package test;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Properties;

public class ReplicationHostManagement {

	private static String REP_URL = "jdbc:mysql:replication://localhost:3306,localhost:3307/test";

	private static Properties REP_PROPS = new Properties();

	static {
		REP_PROPS.put("user", "root");
		REP_PROPS.put("password", "");
		REP_PROPS.put("replicationConnectionGroup", "repGroup");
		REP_PROPS.put("replicationEnableJMX", "true");

	}

	public static void main(String[] args) throws Exception {
		System.out.println("Starting replication host management demo...");

		int threads = 3;
		if (args.length > 0) {
			try {
				threads = Integer.parseInt(args[0]);
			} catch (Exception e) {
			}
		}
		for (int i = 0; i < threads; i++) {
			System.out.println("Starging thread #" + (1 + i));
			new Thread(new Repeater(i)).start();
		}

	}

	public static class Repeater implements Runnable {
		private int thread;

		public Repeater(int t) {
			this.thread = t;
		}

		public void run() {
			long rand = Math.round(20 * Math.random()) + 1;
			for (int i = 0; i < rand; i++) {
				try {
					Connection c = getNewConnection();
					long randTrans = Math.round(100 * Math.random()) + 1;
					for (int j = 0; j < randTrans; j++) {
						executeSimpleTransaction(c, this.thread, i, j);
						// Thread.sleep(Math.round(1000 * Math.random()));
					}
					c.close();
					Thread.sleep(Math.round(100 * Math.random()));
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		}
	}

	static Connection getNewConnection() throws SQLException,
			ClassNotFoundException {
		Class.forName("com.mysql.jdbc.Driver");
		return DriverManager.getConnection(REP_URL, REP_PROPS);
	}

	static void executeSimpleTransaction(Connection c, int thread, int conn,
			int trans) throws SQLException {
		boolean readOnly = trans % 2 == 0;
		c.setReadOnly(readOnly);
		c.setAutoCommit(false);
		Statement s = c.createStatement();
		s.executeQuery("SELECT SLEEP(1) /* Thread:  " + thread
				+ ", connection: " + conn + ", transaction: " + trans
				+ ", read-only: " + c.isReadOnly() + " */");
		c.commit();

	}

}
